@@ -54,20 +54,24 @@ class Snippet:
         """Snippet's lang
 
         Returns:
-            str?: lang
+            str: lang
         """
+        lang = ""
         if len(self.__header) >= 1:
-            return self.__header[0]
+            lang = self.__header[0].lower()
+        return lang
 
     @property
     def type(self):
         """Snippet's type
 
         Returns:
-            str?: type
+            str: type
         """
+        type = ""
         if len(self.__header) >= 2:
-            return self.__header[1]
+            type = self.__header[1].lower()
+        return type
 
     @property
     def props(self):
@@ -79,8 +83,8 @@ class Snippet:
         props = {}
         for item in self.__header[2:]:
             parts = item.split("=")
-            name = parts[0]
-            value = parts[1] if len(parts) == 2 else True
+            name = parts[0].lower()
+            value = parts[1].lower() if len(parts) == 2 else True
             props[name] = value
         return props
 
